@@ -291,7 +291,7 @@ desktop_thumbnailer_load_thumbnail (DesktopThumbnailer *thumbnailer,
 
       g_object_get (G_OBJECT (thumbnailer), "exec", &exec, NULL);
       res = desktop_thumbnailer_exec_parse (exec,
-                                            path,
+                                            path != NULL ? path : "",
                                             uri,
                                             size,
                                             tmpfilepath,
@@ -407,13 +407,13 @@ desktop_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
 
   if (error != NULL)
     {
-      g_signal_emit_by_name (thumbnailer, "error", uri,
+      g_signal_emit_by_name (thumbnailer, "error", info,
                              error->domain, error->code, error->message);
       g_error_free (error);
     }
   else
     {
-      g_signal_emit_by_name (thumbnailer, "ready", uri);
+      g_signal_emit_by_name (thumbnailer, "ready", info);
     }
 
   g_object_unref (thumbnail);
