@@ -429,7 +429,7 @@ font_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
       /* there was an error in the freetype initialization, abort */
       error_msg = g_strdup_printf (_("Could not initialize freetype: %s"),
                                    ft_strerror (font_thumbnailer->library_error));
-      g_signal_emit_by_name (thumbnailer, "error", uri,
+      g_signal_emit_by_name (thumbnailer, "error", info,
                              TUMBLER_ERROR, TUMBLER_ERROR_UNSUPPORTED, error_msg);
       g_free (error_msg);
       return;
@@ -442,7 +442,7 @@ font_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
       /* there was an error, emit error signal */
       error_msg = g_strdup_printf (_("Could not load file contents: %s"), 
                                    error->message);
-      g_signal_emit_by_name (thumbnailer, "error", uri,
+      g_signal_emit_by_name (thumbnailer, "error", info,
                              error->domain, error->code, error_msg);
       g_free (error_msg);
 
@@ -462,7 +462,7 @@ font_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
       /* the font file could not be loaded, emit an error signal */
       error_msg = g_strdup_printf (_("Could not open font file: %s"),
                                    ft_strerror (ft_error));
-      g_signal_emit_by_name (thumbnailer, "error", uri,
+      g_signal_emit_by_name (thumbnailer, "error", info,
                              TUMBLER_ERROR, TUMBLER_ERROR_NO_CONTENT, error_msg);
       g_free (error_msg);
 
@@ -487,7 +487,7 @@ font_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
               /* emit an error signal */
               error_msg = g_strdup_printf (_("Could not set the character map: %s"),
                                            ft_strerror (ft_error));
-              g_signal_emit_by_name (thumbnailer, "error", uri,
+              g_signal_emit_by_name (thumbnailer, "error", info,
                                      TUMBLER_ERROR, TUMBLER_ERROR_INVALID_FORMAT, error_msg);
               g_free (error_msg);
 
@@ -515,7 +515,7 @@ font_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
       /* emit an error signal */
       error_msg = g_strdup_printf (_("Could not render glyphs: %s"),
                                    ft_strerror (ft_error));
-      g_signal_emit_by_name (thumbnailer, "error", uri,
+      g_signal_emit_by_name (thumbnailer, "error", info,
                              TUMBLER_ERROR, TUMBLER_ERROR_INVALID_FORMAT, error_msg);
       g_free (error_msg);
 
@@ -547,14 +547,14 @@ font_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
   if (error != NULL)
     {
       /* emit an error signal */
-      g_signal_emit_by_name (thumbnailer, "error", uri,
+      g_signal_emit_by_name (thumbnailer, "error", info,
                              error->domain, error->code, error->message);
       g_error_free (error);
     }
   else
     {
       /* otherwise, the thumbnail is now ready */
-      g_signal_emit_by_name (thumbnailer, "ready", uri);
+      g_signal_emit_by_name (thumbnailer, "ready", info);
     }
 
   /* clean up */
