@@ -549,7 +549,7 @@ gst_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
   if (tumbler_util_guess_is_sparse (info))
   {
     g_debug ("Video file '%s' is probably sparse, skipping", uri);
-    g_signal_emit_by_name (thumbnailer, "error", uri, TUMBLER_ERROR,
+    g_signal_emit_by_name (thumbnailer, "error", info, TUMBLER_ERROR,
                            TUMBLER_ERROR_NO_CONTENT, TUMBLER_ERROR_MESSAGE_CREATION_FAILED);
 
     return;
@@ -562,7 +562,7 @@ gst_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
   g_object_unref (file);
   if (stream == NULL)
     {
-      g_signal_emit_by_name (thumbnailer, "error", uri,
+      g_signal_emit_by_name (thumbnailer, "error", info,
                              error->domain, error->code, error->message);
       g_error_free (error);
 
@@ -574,7 +574,7 @@ gst_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
   g_object_unref (stream);
   if (size == -1)
     {
-      g_signal_emit_by_name (thumbnailer, "error", uri,
+      g_signal_emit_by_name (thumbnailer, "error", info,
                              error->domain, error->code, error->message);
       g_error_free (error);
 
@@ -589,7 +589,7 @@ gst_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
   g_free (claimed_type);
   if (uncertain || ! equals)
     {
-      g_signal_emit_by_name (thumbnailer, "error", uri, TUMBLER_ERROR,
+      g_signal_emit_by_name (thumbnailer, "error", info, TUMBLER_ERROR,
                              TUMBLER_ERROR_INVALID_FORMAT, TUMBLER_ERROR_MESSAGE_CREATION_FAILED);
       return;
     }
@@ -649,13 +649,13 @@ gst_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
 
       if (error != NULL)
         {
-          g_signal_emit_by_name (thumbnailer, "error", uri,
+          g_signal_emit_by_name (thumbnailer, "error", info,
                                  error->domain, error->code, error->message);
           g_error_free (error);
         }
       else
         {
-          g_signal_emit_by_name (thumbnailer, "ready", uri);
+          g_signal_emit_by_name (thumbnailer, "ready", info);
         }
     }
   else
@@ -665,7 +665,7 @@ gst_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
         g_set_error (&error, TUMBLER_ERROR, TUMBLER_ERROR_NO_CONTENT,
                      TUMBLER_ERROR_MESSAGE_CREATION_FAILED);
 
-      g_signal_emit_by_name (thumbnailer, "error", uri,
+      g_signal_emit_by_name (thumbnailer, "error", info,
                              error->domain, error->code, error->message);
       g_error_free (error);
     }
