@@ -101,10 +101,10 @@ tumbler_thumbnailer_default_init (TumblerThumbnailerIface *klass)
                   G_STRUCT_OFFSET (TumblerThumbnailerIface, ready),
                   NULL,
                   NULL,
-                  g_cclosure_marshal_VOID__STRING,
+                  g_cclosure_marshal_VOID__OBJECT,
                   G_TYPE_NONE,
                   1,
-                  G_TYPE_STRING);
+                  G_TYPE_OBJECT);
 
   tumbler_thumbnailer_signals[SIGNAL_ERROR] =
     g_signal_new ("error",
@@ -113,10 +113,10 @@ tumbler_thumbnailer_default_init (TumblerThumbnailerIface *klass)
                   G_STRUCT_OFFSET (TumblerThumbnailerIface, error),
                   NULL,
                   NULL,
-                  tumbler_marshal_VOID__STRING_UINT_INT_STRING,
+                  tumbler_marshal_VOID__OBJECT_UINT_INT_STRING,
                   G_TYPE_NONE,
                   4,
-                  G_TYPE_STRING,
+                  G_TYPE_OBJECT,
                   G_TYPE_UINT,
                   G_TYPE_INT,
                   G_TYPE_STRING);
